
#define LCD_RS PIN_A2				// LCD display register select
#define LCD_EN PIN_A0				// LCD display enable
// data output pins are hardwired as
// PIN_B4 (LSB) to PIN_B7 (MSB)
// see lcd_send_nibble() if you need to change them

#define lcd_line_two 0x40    // LCD RAM address for the second line


void lcd_send_nibble(byte n) {
	output_b(n | 1);		// PIN_B1 is chip select for ADE chip and must be held high
    delay_cycles(1);
    output_high(LCD_EN);
    delay_us(2);
    output_low(LCD_EN);
    delay_us(2);
}


void lcd_send_byte(short RegSel, byte n) {
    output_bit(LCD_RS, RegSel);
    delay_cycles(1);   
    lcd_send_nibble(n & 0xf0);
    lcd_send_nibble(n << 4);
    delay_us(40);
	output_low(LCD_RS);
}


void lcd_clear() {
	lcd_send_byte(0, 0b00000001);	//display clear
	delay_ms(2);
	lcd_send_byte(0,0x80);			// goto top left corner
}	
	

void lcd_init() {
    BYTE i;
    
    output_low(LCD_EN);
	output_low(LCD_RS);
	delay_ms(2);

    for(i=1;i<=3;++i) {
    	lcd_send_nibble(3<<4);		// get the attention of the display
    	delay_ms(5);
    }
   
    lcd_send_nibble(2<<4);			// set 4 bit data
	lcd_clear();					// this seems to help reset the Altronics display
	lcd_send_byte(0, 0b00101100);	// 4-bits, 2 lines, 5x10 dots
	lcd_send_byte(0, 0b00101100);	// repeat again, this seems to help reset
	lcd_send_byte(0, 0b00001100);	// blinking off, cursor off
	lcd_send_byte(0, 0b00000110);	// entry mode. cursor moves right, display not shifted
	lcd_clear();
}


void lcd_gotoxy( BYTE x, BYTE y) {
   BYTE address;

   if(y!=1)
     address=lcd_line_two;
   else
     address=0;
   address+=x-1;
   lcd_send_byte(0,0x80|address);
}


void lcd_putc( char c) {
//   	switch (c) {
//    	case '\f'   : lcd_clear();            break;
//     	case '\n'   : lcd_gotoxy(1,2);        break;
//     	default     : lcd_send_byte(1,c);     break;
//   }
	lcd_send_byte(1,c);
}
